@@ -18,23 +18,26 @@
 */
 
 #include <Lum/Base/L10N.h>
-#include <Lum/Base/Path.h>
 #include <Lum/Base/String.h>
 
 #include <Lum/Def/Menu.h>
 #include <Lum/Def/MultiView.h>
+#include <Lum/Def/OneOfN.h>
+#include <Lum/Def/Props.h>
 
 #include <Lum/Dlg/About.h>
+#include <Lum/Dlg/Properties.h>
 
-#include <Lum/OS/Main.h>
+#include <Lum/Manager/Behaviour.h>
+#include <Lum/Manager/FileSystem.h>
 
+#include <Lum/Application.h>
 #include <Lum/Dialog.h>
 #include <Lum/Panel.h>
 #include <Lum/Tab.h>
 
 #include "Calc.h"
 #include "Configuration.h"
-#include "ConfigDialog.h"
 #include "FormatConversion.h"
 #include "Formula.h"
 #include "Plot.h"
@@ -132,7 +135,7 @@ public:
 
     multiView.SetMenu(preMenu,postMenu);
 
-    Lum::OS::display->GetBehaviour()->ApplyMultiViewDlg(this,multiView);
+    Lum::Manager::Behaviour::Instance()->ApplyMultiViewDlg(this,multiView);
 
     Dialog::PreInit();
   }
@@ -150,6 +153,17 @@ public:
     }
     else if (model==settingsAction &&
              settingsAction->IsFinished()) {
+      Lum::Def::PropGroup *props=new Lum::Def::PropGroup();
+
+      props->OneOfN(Lum::Def::OneOfN(Lum::Def::Desc(L"Calc trigometric mode"), calcTrigoMode)
+      .AddChoice(Lum::Def::Desc(L"Degree"))
+      .AddChoice(Lum::Def::Desc(L"Radiant")));
+
+      Lum::Dlg::Properties::Show(this,props);
+
+      delete props;
+
+      /*
       ConfigDialog *dialog;
 
       dialog=new ConfigDialog();
@@ -159,7 +173,7 @@ public:
         dialog->Close();
       }
 
-      delete dialog;
+      delete dialog;*/
     }
     else if (model==aboutAction &&
              aboutAction->IsFinished()) {
@@ -170,19 +184,10 @@ public:
   }
 };
 
-class Main : public Lum::OS::MainDialog<MainWindow>
+class Main : public Lum::GUIApplication<MainWindow>
 {
 public:
-  bool Prepare()
-  {
-#if defined(APP_DATADIR)
-    Lum::Base::Path::SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
-#endif
-
-   return Lum::OS::MainDialog<MainWindow>::Prepare();
-  }
-
-  Main()
+  bool Initialize()
   {
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
     info.SetVersion(Lum::Base::StringToWString(PACKAGE_VERSION));
@@ -191,6 +196,12 @@ public:
     info.SetContact(L"Tim Teulings <tim@teulings.org>");
     info.SetCopyright(L"(c) 2007, Tim Teulings");
     info.SetLicense(L"GNU Public License (GPL)");
+  
+#if defined(APP_DATADIR)
+    Lum::Manager::FileSystem::Instance()->SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
+#endif
+
+   return Lum::GUIApplication<MainWindow>::Initialize();
   }
 };
 
